# Chromosome
Chromosome is an open-source Evolutionary Algorithm Architecture.

## [Documentation]:
[Documentation](https://twguest.github.io/Chromosome/)

## [Usage]:
[Example 1](https://twguest.github.io/Chromosome/example1)

## [Publications]:
[Information, Complexity and Life on Mars](https://medium.com/@treyguest/information-complexity-and-life-on-mars-bd70267e0888)

## How to Install:

### Via Pip:


```python
pip install Chromosome
```

### Via Conda:


```python
conda install -c twguest chromosome 
```

## [Credits]:
Trey Guest - La Trobe University - @twguest
